@@ -34,6 +34,16 @@ namespace LongoMatch.Interfaces
 		void UpdateProject(Project project);
 		
 		bool Exists(Project project);
+		
+		bool Backup ();
+		
+		bool Delete ();
+		
+		string Name {get;}
+		
+		DateTime LastBackup {get;}
+		
+		int Count {get;}
 	}
 }
 
