@@ -495,10 +495,10 @@ namespace LongoMatch.Gui
 			if(InSegment()) {
 				currentTime -= segmentStartTime;
 				currentposition = (float)currentTime/(float)(segmentStopTime-segmentStartTime);
-				slength = TimeString.MSecondsToSecondsString(segmentStopTime-segmentStartTime);
+				slength = TimeString.MSecondsToMSecondsString(segmentStopTime-segmentStartTime);
 			}
 
-			timelabel.Text = TimeString.MSecondsToSecondsString(currentTime) + "/" + slength;
+			timelabel.Text = TimeString.MSecondsToMSecondsString(currentTime) + "/" + slength;
 			timescale.Value = currentposition;
 			if(Tick != null)
 				Tick(o, args.CurrentTime, args.StreamLength, args.CurrentPosition, args.Seekable);
