@@ -30,6 +30,7 @@ using LongoMatch.Store;
 using LongoMatch.Store.Templates;
 using LongoMatch.Video.Utils;
 using Mono.Unix;
+using LongoMatch.Gui.Helpers;
 
 namespace LongoMatch.Gui.Component
 {
@@ -289,7 +290,7 @@ namespace LongoMatch.Gui.Component
 			var desc = project.Description;
 			/* In case the framerate changed, update each play with the new
 			 * framerate */
-			if (desc.File.Fps != mFile.Fps) {
+			if (desc.File != null && desc.File.Fps != mFile.Fps) {
 				foreach (Play play in project.AllPlays ()) {
 					play.Fps = mFile.Fps;
 				}
@@ -463,7 +464,7 @@ namespace LongoMatch.Gui.Component
 				                                 FileChooserAction.Save,
 				                                 "gtk-cancel",ResponseType.Cancel,
 				                                 "gtk-save",ResponseType.Accept);
-				fChooser.SetCurrentFolder(Config.VideosDir());
+				fChooser.SetCurrentFolder(Config.VideosDir);
 				fChooser.DoOverwriteConfirmation = true;
 				if(fChooser.Run() == (int)ResponseType.Accept)
 					fileEntry.Text = fChooser.Filename;
@@ -517,8 +518,7 @@ namespace LongoMatch.Gui.Component
 						fileEntry.Text = filename;
 					}
 					catch(Exception ex) {
-						MessagePopup.PopupMessage(this, MessageType.Error,
-						                          ex.Message);
+						MessagesHelpers.ErrorMessage (this, ex.Message);
 					}
 					finally {
 						md.Destroy();
