@@ -25,6 +25,7 @@ using LongoMatch.Gui;
 using LongoMatch.Video.Utils;
 using LongoMatch.Store;
 using LongoMatch.Interfaces;
+using LongoMatch.Gui.Helpers;
 
 namespace LongoMatch.Gui.Dialog
 {
@@ -79,12 +80,13 @@ namespace LongoMatch.Gui.Dialog
 		
 		protected void OnAddbuttonClicked (object sender, System.EventArgs e)
 		{
-			List<string> paths = GUIToolkit.Instance.OpenFiles (Catalog.GetString("Add file"), null,
-			                                                    Config.HomeDir(), null, null);
+			var msg = Catalog.GetString("Add file");
+			List<string> paths = FileChooserHelper.OpenFiles (this, msg, null,
+			                                                  Config.HomeDir, null, null);
 			List<string> errors = new List<string>();
 			foreach (string path in paths) {
 				try {
-					MediaFile file = PreviewMediaFile.DiscoverFile(path);
+					MediaFile file = PreviewMediaFile.DiscoverFile(path, false);
 					store.AppendValues (file);
 					Files.Add (file);
 				} catch (Exception) {
@@ -113,11 +115,11 @@ namespace LongoMatch.Gui.Dialog
 
 		protected void OnOpenbuttonClicked (object sender, System.EventArgs e)
 		{
-			string path = GUIToolkit.Instance.SaveFile (Catalog.GetString("Add file"),
-			                                            "NewVideo.mp4",
-			                                            Config.VideosDir(),
-			                                            Catalog.GetString("MP4 file"),
-			                                            "mp4");
+			string path = FileChooserHelper.SaveFile(this, Catalog.GetString("Add file"),
+			                                         "NewVideo.mp4",
+			                                         Config.VideosDir,
+			                                         Catalog.GetString("MP4 file"),
+			                                        new string[] {"mp4"});
 			outputFile = System.IO.Path.ChangeExtension (path, "mp4");
 			filelabel.Text = outputFile;
 			CheckStatus ();
