@@ -35,6 +35,7 @@ using LongoMatch.Store;
 using LongoMatch.Store.Templates;
 using LongoMatch.Video.Common;
 using LongoMatch.Gui.Component;
+using LongoMatch.Gui.Helpers;
 
 
 namespace LongoMatch.Gui
@@ -82,6 +83,7 @@ namespace LongoMatch.Gui
 		public event ManageTeamsHandler ManageTeamsEvent;
 		public event ManageCategoriesHandler ManageCategoriesEvent;
 		public event ManageProjects ManageProjectsEvent;
+		public event ManageDatabases ManageDatabasesEvent;
 		public event ApplyCurrentRateHandler ApplyRateEvent;
 		
 		/* Game Units events */
@@ -123,20 +125,22 @@ namespace LongoMatch.Gui
 			guTimeline = new GameUnitsTimelineWidget ();
 			downbox.PackStart(guTimeline, true, true, 0);
 			
+			TagSubcategoriesAction.Active = !Config.FastTagging;
+			
 			playercapturer.Mode = PlayerCapturerBin.PlayerOperationMode.Player;
-			playercapturer.SetLogo(System.IO.Path.Combine(Config.ImagesDir(),"background.png"));
+			playercapturer.SetLogo(System.IO.Path.Combine(Config.ImagesDir,"background.png"));
 			playercapturer.LogoMode = true;
 			playercapturer.Tick += OnTick;
 			playercapturer.Detach += DetachPlayer;
 
-			playercapturer.Logo = System.IO.Path.Combine(Config.ImagesDir(),"background.png");
+			playercapturer.Logo = System.IO.Path.Combine(Config.ImagesDir,"background.png");
 			playercapturer.CaptureFinished += (sender, e) => {CloseCaptureProject();};
 			
 			buttonswidget.Mode = TagMode.Predifined;
 			ConnectSignals();
 			ConnectMenuSignals();
 			
-			if (!Config.useGameUnits)
+			if (!Config.UseGameUnits)
 				GameUnitsViewAction.Visible = false;
 			
 			MenuItem parent = ImportProjectActionMenu;
@@ -310,6 +314,7 @@ namespace LongoMatch.Gui
 			CategoriesTemplatesManagerAction.Activated += (o, e) => {EmitManageCategories();};
 			TeamsTemplatesManagerAction.Activated += (o, e) => {EmitManageTeams();};
 			ProjectsManagerAction.Activated += (o, e) => {EmitManageProjects();};
+			DatabasesManagerAction.Activated +=  (o, e) => {EmitManageDatabases();};
 		}
 		
 		void DetachPlayer (bool detach) {
@@ -336,7 +341,7 @@ namespace LongoMatch.Gui
 				playercapturer.Reparent(box);
 				buttonswidget.Visible = true;
 				timeline.Visible = true;
-				if (Config.useGameUnits) {
+				if (Config.UseGameUnits) {
 					guTimeline.Visible = true;
 					gameunitstaggerwidget1.Visible = true;
 				}
@@ -373,7 +378,7 @@ namespace LongoMatch.Gui
 				Title = System.IO.Path.GetFileNameWithoutExtension(desc.File.FilePath) +
 				        " - " + Constants.SOFTWARE_NAME;
 				playercapturer.LogoMode = false;
-				timeline.Project = project;
+				timeline.SetProject (project, filter);
 				guTimeline.Project = project;
 
 			} else {
@@ -385,7 +390,6 @@ namespace LongoMatch.Gui
 				} else {
 					playercapturer.Mode = PlayerCapturerBin.PlayerOperationMode.PreviewCapturer;
 				}
-				TaggingViewAction.Active = true;
 			}
 			
 			openedProject = project;
@@ -428,13 +432,13 @@ namespace LongoMatch.Gui
 		private void MakeActionsSensitive(bool sensitive, ProjectType projectType) {
 			bool sensitive2 = sensitive && projectType == ProjectType.FileProject;
 			CloseProjectAction.Sensitive=sensitive;
-			SaveProjectAction.Sensitive = sensitive;
 			TaggingViewAction.Sensitive = sensitive;
 			ManualTaggingViewAction.Sensitive = sensitive;
 			GameUnitsViewAction.Sensitive = sensitive2 && gameUnitsActionVisible;
 			TimelineViewAction.Sensitive = sensitive2;
 			ExportProjectAction1.Sensitive = sensitive2;
 			HideAllWidgetsAction.Sensitive=sensitive2;
+			SaveProjectAction.Sensitive = sensitive2;
 		}
 
 		private void ShowWidgets() {
@@ -579,7 +583,7 @@ namespace LongoMatch.Gui
 			timeline.Visible = !action.Active && TimelineViewAction.Active;
 			buttonswidget.Visible = !action.Active &&
 				(TaggingViewAction.Active || ManualTaggingViewAction.Active);
-			if (Config.useGameUnits) {
+			if (Config.UseGameUnits) {
 				guTimeline.Visible = !action.Visible && GameUnitsViewAction.Active;
 				gameunitstaggerwidget1.Visible = !action.Active && (GameUnitsViewAction.Active || 
 					TaggingViewAction.Active || ManualTaggingViewAction.Active);
@@ -599,7 +603,7 @@ namespace LongoMatch.Gui
 			
 			buttonswidget.Visible = action == ManualTaggingViewAction || sender == TaggingViewAction;
 			timeline.Visible = action == TimelineViewAction;
-			if (Config.useGameUnits) {
+			if (Config.UseGameUnits) {
 				guTimeline.Visible = action == GameUnitsViewAction;
 				gameunitstaggerwidget1.Visible = buttonswidget.Visible || guTimeline.Visible;
 			}
@@ -730,7 +734,7 @@ namespace LongoMatch.Gui
 
 		protected virtual void OnMultimediaError(object o, string message)
 		{
-			MessagePopup.PopupMessage(this, MessageType.Error,
+			MessagesHelpers.ErrorMessage (this,
 				Catalog.GetString("The following error happened and" +
 				" the current project will be closed:")+"\n" + message);
 			EmitCloseOpenedProject(true);
@@ -873,6 +877,12 @@ namespace LongoMatch.Gui
 				ManageProjectsEvent();
 		}
 		
+		private void EmitManageDatabases()
+		{
+			if (ManageDatabasesEvent != null)
+				ManageDatabasesEvent();
+		}
+		
 		private void EmitNewPlaylist() {
 			if (NewPlaylistEvent != null)
 				NewPlaylistEvent();
@@ -917,7 +927,6 @@ namespace LongoMatch.Gui
 			if (KeyPressed != null)
 				KeyPressed(sender, key, modifier);
 		}
-
 		#endregion
 	}
 }
