@@ -664,6 +664,8 @@ gst_camera_capturer_update_device_id (GstCameraCapturer *gcc)
     prop_name = "guid";
   else if (!g_strcmp0 (gcc->priv->source_element_name, "v4l2src"))
     prop_name = "device";
+  else if (!g_strcmp0 (gcc->priv->source_element_name, "filesrc"))
+    prop_name = "location";
   else if (!g_strcmp0 (gcc->priv->source_element_name, "gsettingsvideosrc"))
     prop_name = NULL;
   else
@@ -871,7 +873,7 @@ gst_camera_capturer_prepare_uri_source (GstCameraCapturer *gcc)
 static GstElement *
 gst_camera_capturer_prepare_dv_source (GstCameraCapturer *gcc)
 {
-  GstElement *bin, *decodebin, *deinterlacer;
+  GstElement *bin, *decodebin, *colorspace, *deinterlacer;
   GstPad *video_pad, *src_pad;
 
   GST_INFO_OBJECT (gcc, "Creating dv source");
@@ -881,9 +883,11 @@ gst_camera_capturer_prepare_dv_source (GstCameraCapturer *gcc)
   gcc->priv->source_decoder_bin = gst_bin_new ("decoder");
   bin = gcc->priv->source_decoder_bin;
   decodebin = gst_element_factory_make ("decodebin2", NULL);
-  deinterlacer = gst_element_factory_make ("ffdeinterlace", "video-pad");
+  colorspace = gst_element_factory_make ("ffmpegcolorspace", "video-pad");
+  deinterlacer = gst_element_factory_make ("ffdeinterlace", NULL);
 
-  gst_bin_add_many (GST_BIN (bin), decodebin, deinterlacer, NULL);
+  gst_bin_add_many (GST_BIN (bin), decodebin, colorspace, deinterlacer, NULL);
+  gst_element_link (colorspace, deinterlacer);
 
   /* add ghostpad */
   video_pad = gst_element_get_static_pad (deinterlacer, "src");
@@ -1258,7 +1262,7 @@ gst_camera_capturer_create_preview(GstCameraCapturer *gcc)
   v_decoder = gst_element_factory_make("decodebin2", "preview-decoder");
 
   video_bin = gst_parse_bin_from_description(
-      "videoscale ! ffmpegcolorspace ! autovideosink name=videosink", TRUE, NULL);
+      "videoscale ! ffmpegcolorspace ! " DEFAULT_VIDEO_SINK " name=videosink sync=false", TRUE, NULL);
 
   gcc->priv->preview_bin = gst_bin_new("preview_bin");
   gst_bin_add_many (GST_BIN(gcc->priv->preview_bin), v_decoder, video_bin, NULL);
@@ -1378,6 +1382,11 @@ gst_camera_capturer_create_video_source (GstCameraCapturer * gcc,
       gst_camera_capturer_prepare_uri_source (gcc);
       gst_camera_capturer_create_remainig (gcc);
       return TRUE;
+    case CAPTURE_SOURCE_TYPE_FILE:
+      GST_INFO_OBJECT(gcc, "Creating file video source");
+      source_desc = "filesrc";
+      gcc->priv->source_element_name = source_desc;
+      break;
     default:
       g_assert_not_reached();
   }
@@ -1386,7 +1395,9 @@ gst_camera_capturer_create_video_source (GstCameraCapturer * gcc,
    * since the device is set in getcaps and can't be changed later */
   if (!g_strcmp0 (gcc->priv->source_element_name, "dshowvideosrc")) {
     source_str = g_strdup_printf("%s device-name=\"%s\" name=source ! "
-        "typefind name=typefind", source_desc, gcc->priv->device_id);
+        "video/x-raw-yuv; video/x-raw-rgb; "
+        "video/x-dv, systemstream=(boolean)True "
+        "! typefind name=typefind", source_desc, gcc->priv->device_id);
   } else {
     source_str = g_strdup_printf("%s name=source %s ! typefind name=typefind",
         source_desc, filter);
@@ -1839,6 +1850,8 @@ gst_camera_capturer_enum_devices (gchar * device_name)
   else if (!g_strcmp0 (device_name, "v4l2src") ||
       !g_strcmp0 (device_name, "osxvideosrc"))
     prop_name = "device";
+  else if (!g_strcmp0 (device_name, "filesrc"))
+    prop_name = "location";
   else
     prop_name = "device-name";
 
