@@ -24,6 +24,7 @@
 #include <gtk/gtk.h>
 
 #include "gst-video-encoder.h"
+#include "video-utils.h"
 
 
 GST_DEBUG_CATEGORY (_video_encoder_gst_debug_cat);
@@ -59,6 +60,8 @@ struct GstVideoEncoderPrivate
   GstElement *encoder_bin;
   GstElement *video_enc;
   GstElement *audio_enc;
+  GstElement *vqueue;
+  GstElement *aqueue;
   GstElement *muxer;
   GstElement *filesink;
 
@@ -66,7 +69,10 @@ struct GstVideoEncoderPrivate
   GstBus *bus;
   gulong sig_bus_async;
 
-  gboolean drained;
+  gboolean video_drained;
+  gboolean audio_drained;
+  GstPad *video_pad;
+  GstPad *audio_pad;
   GstClockTime total_duration;
   guint update_id;
 };
@@ -223,16 +229,17 @@ gst_video_encoder_create_encoder_bin (GstVideoEncoder *gve)
   audioconvert = gst_element_factory_make("audioconvert", NULL);
   audioresample = gst_element_factory_make("audioresample", NULL);
   gve->priv->filesink = gst_element_factory_make("filesink", NULL);
-  aqueue = gst_element_factory_make ("queue", "audio_queue");
-  vqueue = gst_element_factory_make ("queue", "video_queue");
+  aqueue = gst_element_factory_make ("queue2", "audio_queue");
+  vqueue = gst_element_factory_make ("queue2", "video_queue");
   a_identity = gst_element_factory_make ("identity", "audio_identity");
   v_identity = gst_element_factory_make ("identity", "video_identity");
+  gve->priv->aqueue = aqueue;
+  gve->priv->vqueue = vqueue;
 
 
   /* Increase audio queue size for h264 encoding as the encoder queues 2 seconds
    * of video */
   g_object_set (aqueue, "max-size-time", 5 * GST_SECOND, NULL);
-  g_object_set (aqueue, "max-size-buffers", 0, NULL);
 
   /* Set caps for the encoding resolution */
   video_caps = gst_caps_new_simple ("video/x-raw-yuv", NULL);
@@ -305,6 +312,14 @@ cb_handle_eos (GstPad *pad, GstEvent *event, GstVideoEncoder *gve)
   if (event->type == GST_EVENT_EOS) {
     GST_DEBUG_OBJECT (gve, "Dropping EOS on pad %s:%s",
         GST_DEBUG_PAD_NAME (pad));
+    if (pad == gve->priv->audio_pad) {
+      gve->priv->audio_drained = TRUE;
+    } else if (pad == gve->priv->video_pad) {
+      gve->priv->video_drained = TRUE;
+    }
+    if (gve->priv->audio_drained && gve->priv->video_drained) {
+      g_idle_add ((GSourceFunc)gst_video_encoder_select_next_file, gve);
+    }
     return FALSE;
   }
   return TRUE;
@@ -317,6 +332,7 @@ cb_new_pad (GstElement *decodebin, GstPad *pad, GstVideoEncoder *gve)
   GstCaps *caps;
   const GstStructure *s;
   const gchar *mime;
+  gboolean is_video;
 
   caps = gst_pad_get_caps_reffed (pad);
   s = gst_caps_get_structure (caps, 0);
@@ -324,8 +340,10 @@ cb_new_pad (GstElement *decodebin, GstPad *pad, GstVideoEncoder *gve)
 
   if (g_strrstr (mime, "video")) {
     epad = gst_element_get_static_pad (gve->priv->encoder_bin, "video");
+    is_video = TRUE;
   } else if (g_strrstr (mime, "audio")) {
     epad = gst_element_get_static_pad (gve->priv->encoder_bin, "audio");
+    is_video = FALSE;
   }
 
   if (epad && !gst_pad_is_linked (epad)) {
@@ -333,6 +351,11 @@ cb_new_pad (GstElement *decodebin, GstPad *pad, GstVideoEncoder *gve)
     if (gst_pad_link (pad, epad)) {
       g_signal_emit (gve, gve_signals[SIGNAL_ERROR], 0, "Error linking pads");
     } else {
+      if (is_video) {
+        gve->priv->video_pad = pad;
+      } else {
+        gve->priv->audio_pad = pad;
+      }
       gst_pad_add_event_probe (pad, G_CALLBACK (cb_handle_eos), gve);
     }
   } else {
@@ -341,14 +364,6 @@ cb_new_pad (GstElement *decodebin, GstPad *pad, GstVideoEncoder *gve)
   gst_caps_unref (caps);
 }
 
-static void
-cb_drained (GstElement *decodebin, GstVideoEncoder *gve) {
-  if (!gve->priv->drained) {
-    g_idle_add ((GSourceFunc)gst_video_encoder_select_next_file, gve);
-  }
-  gve->priv->drained = TRUE;
-}
-
 static void
 gst_video_encoder_create_source (GstVideoEncoder *gve, gchar *location)
 {
@@ -361,10 +376,10 @@ gst_video_encoder_create_source (GstVideoEncoder *gve, gchar *location)
   gve->priv->source_bin = gst_element_factory_make ("uridecodebin", NULL);
   g_object_set (gve->priv->source_bin, "uri", location, NULL);
   g_signal_connect (gve->priv->source_bin, "pad-added", G_CALLBACK (cb_new_pad), gve);
-  g_signal_connect (gve->priv->source_bin, "drained", G_CALLBACK (cb_drained), gve);
   gst_bin_add (GST_BIN(gve->priv->main_pipeline), gve->priv->source_bin);
   gst_element_sync_state_with_parent (gve->priv->source_bin);
-  gve->priv->drained = FALSE;
+  gve->priv->audio_drained = FALSE;
+  gve->priv->video_drained = FALSE;
 }
 
 static gboolean
@@ -400,6 +415,11 @@ gst_video_encoder_select_next_file (GstVideoEncoder *gve)
     gst_video_encoder_create_source (gve, (gchar *) gve->priv->current_file->data);
   } else {
     GST_INFO_OBJECT (gve, "No more files, sending EOS");
+    /* Enlarge queues to avoid deadlocks */
+    g_object_set (gve->priv->aqueue, "max-size-time", 0,
+        "max-size-bytes", 0, "max-size-buffers", 0, NULL);
+    g_object_set (gve->priv->vqueue, "max-size-time", 0,
+        "max-size-bytes", 0, "max-size-buffers", 0, NULL);
     gst_pad_send_event (audio_pad, gst_event_new_eos());
     gst_pad_send_event (video_pad, gst_event_new_eos());
   }
@@ -725,11 +745,16 @@ gst_video_encoder_start (GstVideoEncoder * gve)
 void
 gst_video_encoder_add_file (GstVideoEncoder * gve, const gchar *file, guint64 duration)
 {
+  gchar *uri;
   g_return_if_fail (gve != NULL);
   g_return_if_fail (GST_IS_VIDEO_ENCODER (gve));
 
   GST_INFO_OBJECT(gve, "Adding file %s", file);
-  gve->priv->input_files = g_list_append (gve->priv->input_files, g_strdup(file));
+  uri = lgm_filename_to_uri (file);
+  if (uri == NULL) {
+    GST_ERROR_OBJECT(gve, "Invalid filename %s", file);
+  }
+  gve->priv->input_files = g_list_append (gve->priv->input_files, uri);
   gve->priv->total_duration += duration * GST_MSECOND;
 }
 
